<?php
/*
Plugin Name: CubePoints
Plugin URI: http://techcube.net/cubepoints/
Description: CubePoints is a point management system designed for Wordpress blogs. Users can earn points by posting comments on your site. To display user's points, just put <code>&lt;?php cp_displayPoints(); ?&gt;</code> in your template or activate the sidebar widget.
Version: 1.2
Author: Jonathan Lau & Peter Zhang
Author URI: http://techcube.net
*/

global $wpdb;

define('POINTS', 'cpoints');
define('PLUGIN_DIR', get_bloginfo('url') . '/wp-content/plugins/cubepoints/');
define('CPDB', $wpdb->prefix  . 'cubepoints');


function cp_install() {
	// set default values
	add_option('cp_comment_points', 5);
	add_option('cp_del_comment_points', 5);
	add_option('cp_post_points', 20);
	add_option('cp_prefix', '$');
	add_option('cp_suffix', '');
	add_option('cp_donation', true);
	add_option('cp_logs_enabled', true);

	// create database
	
	global $wpdb;
	
	$table_name = CPDB;
	if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
	$sql = "CREATE TABLE " . $table_name . " (
		  id bigint(20) NOT NULL AUTO_INCREMENT,
		  uid bigint(20) NOT NULL,
		  type VARCHAR(55) NOT NULL,
		  source bigint(20) NOT NULL,
		  points bigint(20) NOT NULL,
		  timestamp bigint(20) NOT NULL,
		  UNIQUE KEY id (id)
		);";
	
	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);
	add_option("cp_db_version", "1.0");
	
	}
}


function cp_relativeTime($timestamp){
	$difference = time() - $timestamp;
	$periods = array(__('sec','cp'), __('min','cp'), __('hour','cp'), __('day','cp'), __('week','cp'), __('month','cp'), __('year','cp'), __('decade','cp'));
	$lengths = array("60","60","24","7","4.35","12","10");

	if ($difference > 0) { // this was in the past
		$ending = __('ago','cp');
	} else { // this was in the future
		$difference = -$difference;
		$ending = __('to go','cp');
	}		
	for($j = 0; $difference >= $lengths[$j]; $j++)
		$difference /= $lengths[$j];
	$difference = round($difference);
	if($difference != 1) $periods[$j].= __('s','cp');
	$text = "$difference $periods[$j] $ending";
	return $text;
}

function cp_curPageURL() {
 $pageURL = 'http';
 if ($_SERVER["HTTPS"] == "on") {$pageURL .= "s";}
 $pageURL .= "://";
 if ($_SERVER["SERVER_PORT"] != "80") {
  $pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
 } else {
  $pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
 }
 return $pageURL;
}

function cp_log($type, $uid, $points, $source){
	if (get_option('cp_logs_enabled')) {
		$userinfo = get_userdata($uid);
		if($userinfo->user_login==''){ return false; }
		if($points==0){ return false; }
	
		global $wpdb;
	
		$wpdb->query('INSERT INTO `'.CPDB.'` (`id`, `uid`, `type`, `source`, `points`, `timestamp`) VALUES (NULL, \''.$uid.'\', \''.$type.'\', \''.$source.'\', \''.$points.'\', '.time().');');
	
		return true;
	}
}

function cp_currentUser() {
	global $current_user;
	get_currentuserinfo();
	return $current_user->ID;
}

function cp_getPoints($uid) {
	$points = get_usermeta($uid, POINTS);
	if ($points == '') {
	  return 0;
	} else {
	  return $points;
	}
}

function cp_updatePoints($uid, $points) {
	// no negative points 
	if ($points < 0) {
	  $points = 0;
	}
	update_usermeta($uid, POINTS, $points);
}

function cp_alterPoints($uid, $points) {
	cp_updatePoints($uid, cp_getPoints($uid) + $points);
}

// uid1 donates points to uid2 
function cp_donatePoints($uid1, $uid2, $points) {
	$points = (int)$points;
	if ($points < 1) {
	  return(__('Error: You must donate at least 1 point!','cp'));
	}
	if (cp_getPoints($uid1) < $points) {
	  return(__('Error: Insufficient points to donate!','cp'));
	}
	cp_alterPoints($uid1, -$points);
	cp_alterPoints($uid2, $points);

	//log
	cp_log('donate',$uid1,-$points,$uid2);
	cp_log('donate',$uid2,$points,$uid1);

	$user_info = get_userdata($uid2);
	
	return cp_formatPoints($points) . ' '. __('have been donated to','cp') .' ' . $user_info->user_login . '.';
}

function cp_formatPoints($points){
	return get_option('cp_prefix') . $points . get_option('cp_suffix');
}
function cp_getAllPoints(){
	global $wpdb;
	$array = $wpdb->get_results('SELECT id, user_login, meta_value FROM `'.$wpdb->prefix.'users` LEFT JOIN `'.$wpdb->prefix.'usermeta` on '.$wpdb->prefix.'users.id = '.$wpdb->prefix.'usermeta.user_id AND '.$wpdb->prefix.'usermeta.meta_key=\''.POINTS.'\';',ARRAY_A);
	foreach($array as $row=>$data){
		$data['id'] = (int) $data['id'];
		$data['meta_value'] = (int) $data['meta_value'];
		$array[$row] = $data;
	}


function msort($array, $id="id") {
        $temp_array = array();
        while(count($array)>0) {
            $lowest_id = 0;
            $index=0;
            foreach ($array as $item) {
                if (isset($item[$id]) && $array[$lowest_id][$id]) {
                    if ($item[$id]<$array[$lowest_id][$id]) {
                        $lowest_id = $index;
                    }
                }
                $index++;
            }
            $temp_array[] = $array[$lowest_id];
            $array = array_merge(array_slice($array, 0,$lowest_id), array_slice($array, $lowest_id+1));
        }
        return $temp_array;
}

$array = array_reverse(msort($array, 'meta_value'));

	return $array;
}


function cp_displayPoints($uid = 0, $return = 0, $format = 1) {
	if ($uid == 0) {
	  if (!is_user_logged_in()) {
		  return false;
	  }
	  $uid = cp_currentUser();
	}
	if ($format == 1) {
	  $fpoints = cp_formatPoints(cp_getPoints($uid));
	} else {
	  $fpoints = cp_getPoints($uid);
	}
	if (!$return ) {
	  echo $fpoints;
	} else {
	  return $fpoints;
	}
}

function cp_newComment($cid) {
	if (is_user_logged_in()) {
		cp_alterPoints(cp_currentUser(), get_option('cp_comment_points'));
		//log
		cp_log('comment',cp_currentUser(),get_option('cp_comment_points'),$cid);
	}
}

function cp_newPost($pid) {
	$post = get_post($pid);
	$uid = $post->post_author;
	global $wpdb;
	$count = (int) $wpdb->get_var('select count(id) from `'.CPDB.'` where `type` = \'post\' and `source` = ' . $pid);
	if($count==0){
		cp_alterPoints($uid, get_option('cp_post_points'));
		//log
		cp_log('post',$uid,get_option('cp_post_points'),$pid);
	}
}

function cp_rmvComment($cid) {
	$comment = get_comment($cid);
	$uid = $comment->user_id;
	cp_alterPoints($uid, -get_option('cp_del_comment_points'));
	//log
	cp_log('comment',$uid,-get_option('cp_del_comment_points'),$cid);
}

add_action('comment_post', 'cp_newComment');
add_action('delete_comment', 'cp_rmvComment');
add_action('publish_post', 'cp_newPost');

function cp_getPostCount($id){
	global $wpdb;
	return (int) $wpdb->get_var('SELECT count(id) FROM `'.$wpdb->prefix.'posts` where `post_type`=\'post\' and `post_status`=\'publish\' and `post_author`='.$id);
}

function cp_getCommentCount($id){
	global $wpdb;
	return (int) $wpdb->get_var('SELECT count(comment_ID) FROM `'.$wpdb->prefix.'comments` where `user_id`='.$id);
}

function cp_admin_manage()
{

  global $wpdb;
	$cp_admin_manage_totalUsers = $wpdb->get_var('select count(ID) from ' . $wpdb->prefix . 'users');
	
	$cp_admin_manage_numPerPage = 25;
	$cp_admin_manage_totalPages = $cp_admin_manage_totalUsers / $cp_admin_manage_numPerPage;
	
	if((int)$cp_admin_manage_totalPages!=$cp_admin_manage_totalPages){
		$cp_admin_manage_totalPages = (int)$cp_admin_manage_totalPages+1;
	}
	else{
		$cp_admin_manage_totalPages = (int)$cp_admin_manage_totalPages;
	}
	
	if($_GET['p']==''){
		$cp_admin_manage_pageNum = 1;
	}
	else{
		$cp_admin_manage_pageNum = (int) $_GET['p'];
	}

	// calculations for pagination of admin page
	if($cp_admin_manage_pageNum<1||$cp_admin_manage_pageNum>$cp_admin_manage_totalPages){$cp_admin_manage_pageNum=1;}
	$cp_admin_manage_start = $cp_admin_manage_numPerPage * ($cp_admin_manage_pageNum-1) +1;
	$cp_admin_manage_end = $cp_admin_manage_start + $cp_admin_manage_numPerPage-1;
	if($cp_admin_manage_end>$cp_admin_manage_totalUsers){$cp_admin_manage_end=$cp_admin_manage_totalUsers;}


  if ($_POST['cp_alterPoints'] == '1') {
	  $uid = $_POST['cp_alterPoints_userid'];
	  $points = (int)$_POST['cp_alterPoints_newPoints'];


	  //log
	  cp_log('admin',$uid,$points-cp_getPoints($uid),cp_currentUser());
	  cp_updatePoints($uid, $points);

	  $user_info = get_userdata($uid);

	  echo '<div class="updated"><p><strong>'.__('Points updated for','cp').' ' . $user_info->user_login . '.</strong></p></div>';
  }
  echo '<div class="wrap">';
  echo '<h2>CubePoints - ' . __('Manage', 'cp') . '</h2>';

	if ($_POST['cp_adminUserSearch'] == '') {
		$results = $wpdb->get_results('select * from ' . $wpdb->prefix . 'users ORDER BY user_login ASC LIMIT ' . ($cp_admin_manage_start-1) . ', ' . $cp_admin_manage_numPerPage);
	} else {
		$results = $wpdb->get_results('select * from ' . $wpdb->prefix . 'users where `user_login` LIKE "' . $wpdb->escape($_POST['cp_adminUserSearch']) . '%"');
	}
?>


<?php _e('Use this page to alter the points of your users.', 'cp'); ?>

<form class="search-form" method="post" action="<?php echo $_SERVER['PHP_SELF'] ?>?page=cubepoints/cubepoints.php" style="padding-bottom:30px;">
<p class="search-box">
	<input type="text" class="search-input" name="cp_adminUserSearch" value="<?php echo $_POST['cp_adminUserSearch']; ?>" />
	<input type="submit" value="<?php _e('Search Users', 'cp'); ?>" class="button" />
</p>
</form>



<table class="widefat fixed" cellspacing="0">
<thead>
	<tr>
		<th scope="col"><?php _e('User', 'cp'); ?></th>
		<th scope="col"><?php _e('Email', 'cp'); ?></th>
		<th scope="col"><?php _e('Points', 'cp'); ?></th>
		<th scope="col"><?php _e('Update Points', 'cp'); ?></th>
	</tr>
</thead>
<tfoot>
	<tr>
		<th scope="col"><?php _e('User', 'cp'); ?></th>
		<th scope="col"><?php _e('Email', 'cp'); ?></th>
		<th scope="col"><?php _e('Points', 'cp'); ?></th>
		<th scope="col"><?php _e('Update Points', 'cp'); ?></th>
	</tr>
</tfoot>
<tbody>
	<?php foreach ($results as $result) { ?>
	<tr>
		
			<td style="vertical-align:middle;"><div style="float:left;">
		<?php
	  if (function_exists('get_avatar')) {
		  echo get_avatar($result->ID, $size = '32');
	  } else {
		  //alternate gravatar code for < 2.5
		  $grav_url = "http://www.gravatar.com/avatar.php?gravatar_id=" . md5($result->user_email) . "&size=" . 32;
		  echo "<img src='$grav_url' width='32' height='32' />";
	  }
		?>
				</div>
				<div style="float:left;padding-top:8px;padding-left:12px;font-size:16px;"><?php echo $result->user_login; ?></div></td>
			<td style="vertical-align:middle;"><?php echo $result->user_email; ?></td>
			<td style="vertical-align:middle;font-size:16px;"><?php cp_displayPoints($result->ID); ?></td>
			<td style="vertical-align:middle;">
				<form method="post" action="<?php echo cp_curPageURL(); ?>">
				<input type="hidden" name="cp_alterPoints" value="1" />
				<input type="hidden" name="cp_alterPoints_userid" value="<?php echo $result->ID; ?>" />
				<input type="text" name="cp_alterPoints_newPoints" value="<?php cp_displayPoints($result->ID, 0, 0); ?>" class="widefat" style="width:60%;" />
				<input type="submit" value="<?php _e('Go','cp'); ?>" class="button" style="width:20%;" /></form>
			</td>
		
	</tr>
	<?php } ?>
</tbody>
</table>

<?php

if ($_POST['cp_adminUserSearch'] == ''&&$cp_admin_manage_totalPages>1) {
?>

<div class="tablenav"> 
	<div class="tablenav-pages">

	<span class="displaying-num"><?php _e('Displaying','cp'); ?> <?php echo $cp_admin_manage_start; ?>&#8211;<?php echo $cp_admin_manage_end; ?> <?php _e('of','cp'); ?> <?php echo $cp_admin_manage_totalUsers; ?></span>
	<?php
	
	if($cp_admin_manage_pageNum!=1){
	echo "<a class='prev page-numbers' href='". $_SERVER['PHP_SELF']."?page=cubepoints/cubepoints.php&amp;p=".($cp_admin_manage_pageNum-1)."'>" .'&laquo; '. __('Previous', 'cp') . "</a> ";
	}
	
	$i=1;
	while($i<=$cp_admin_manage_totalPages){
	if($cp_admin_manage_pageNum==$i){
		echo "<span class='page-numbers current'>".$i."</span> ";
	}
	else{
		echo "<a class='page-numbers' href=\"". $_SERVER['PHP_SELF']."?page=cubepoints/cubepoints.php&amp;p=".$i."\">".$i."</a> ";
	}
	$i++;
	}
	
	if($cp_admin_manage_pageNum!=$cp_admin_manage_totalPages){
		echo "<a class='next page-numbers' href='". $_SERVER['PHP_SELF']."?page=cubepoints/cubepoints.php&amp;p=".($cp_admin_manage_pageNum+1)."'>" . __('Next', 'cp') . " &raquo;</a> ";
	}
	
	?>
	</div></div> 
	<?php } 
	if ($_POST['cp_adminUserSearch'] !='') { ?>
	<div class="tablenav"> 
		<div class="tablenav-pages"><a class='page-numbers' href='<?php echo $_SERVER['PHP_SELF']; ?>?page=cubepoints/cubepoints.php'><?php _e('View All Users', 'cp'); ?> &raquo;</a></div></div>
	
	<?php } if($_POST['cp_adminUserSearch'] ==''&&$cp_admin_manage_totalPages==1) {echo '<br />';} ?>
	
	</div>
<?php }
function cp_admin_config()
{
  if ($_POST['cp_admin_form_submit'] == 'Y') {
	  $cp_comment_points = (int)$_POST['cp_comment_points'];
	  $cp_del_comment_points = (int)$_POST['cp_del_comment_points'];
	  $cp_post_points = (int)$_POST['cp_post_points'];
	  $cp_prefix = $_POST['cp_prefix'];
	  $cp_suffix = $_POST['cp_suffix'];
	  $cp_donation = (bool)$_POST['cp_donation'];
	  $cp_logs_enabled = (bool)$_POST['cp_logs_enabled'];
	  update_option('cp_comment_points', $cp_comment_points);
	  update_option('cp_del_comment_points', $cp_del_comment_points);
	  update_option('cp_post_points', $cp_post_points);
	  update_option('cp_prefix', $cp_prefix);
	  update_option('cp_suffix', $cp_suffix);
	  update_option('cp_donation', $cp_donation);
	  update_option('cp_logs_enabled', $cp_logs_enabled);
	  echo '<div class="updated"><p><strong>Options saved.</strong></p></div>';
  }
  if (get_option('cp_donation')) {
	  $cp_donation_checked = " checked='checked'";
  } else {
	  $cp_donation_checked = "";
  }
  if (get_option('cp_logs_enabled')) {
	  $cp_logs_enabled_checked = " checked='checked'";
  } else {
	  $cp_logs_enabled_checked = "";
  }
?>
<div class="wrap">
<h2>CubePoints - <?php _e('Configure', 'cp'); ?></h2>
<?php _e('Configure CubePoints to your liking!', 'cp'); ?><br /><br />
<form name="cp_admin_form" method="post" action="<?php echo str_replace('%7E', '~', $_SERVER['REQUEST_URI']); ?>">
	<input type="hidden" name="cp_admin_form_submit" value="Y" />
	<h3><?php _e('General Settings','cp'); ?></h3>
	<table class="form-table">
		<tr valign="top">
			<th scope="row"><label for="cp_comment_points"><?php _e('Number of points for each comment:', 'cp'); ?></label>
			</th>
			<td valign="middle" width="190"><input type="text" id="cp_comment_points" name="cp_comment_points" value="<?php echo get_option('cp_comment_points'); ?>" size="20" /></td>
			<td><input type="button" onclick="document.getElementById('cp_comment_points').value='0'" value="<?php _e('Do not add points for comments', 'cp'); ?>" class="button" /></td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="cp_comment_points"><?php _e('Number of points subtracted for deleting each comment:','cp'); ?></label>
			</th>
			<td valign="middle"><input type="text" id="cp_del_comment_points" name="cp_del_comment_points" value="<?php echo get_option('cp_del_comment_points'); ?>" size="20" /></td>
			<td><input type="button" onclick="document.getElementById('cp_del_comment_points').value='0'" value="<?php _e('Do not subtract points on comment deletion','cp'); ?>" class="button" /></td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="cp_comment_points"><?php _e('Number of points for each post:','cp'); ?></label>
			</th>
			<td valign="middle"><input type="text" id="cp_post_points" name="cp_post_points" value="<?php echo get_option('cp_post_points'); ?>" size="20" /></td>
			<td><input type="button" onclick="document.getElementById('cp_post_points').value='0'" value="<?php _e('Do not add points for new posts','cp'); ?>" class="button" /></td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="cp_donation"><?php _e('Enable user-to-user donations:','cp'); ?></label>
			</th>
			<td valign="middle"><input id="cp_donation" name="cp_donation" type="checkbox" value="1" <?php echo $cp_donation_checked; ?> /></td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="cp_logs_enabled"><?php _e('Enable logging:', 'cp'); ?></label>
			</th>
			<td valign="middle"><input id="cp_logs_enabled" name="cp_logs_enabled" type="checkbox" value="1" <?php echo $cp_logs_enabled_checked; ?> onclick="if(!this.checked){  if(!confirm('Note: Turning off the logging feature would allow your users to get points by just updating posts.')){this.checked=1;}   }" /></td>
		</tr>
	</table>
	<h3><?php _e('Display Settings','cp'); ?></h3>
	<table class="form-table">
		<tr valign="top">
			<th scope="row"><label for="cp_prefix"><?php _e('Prefix for display of points:', 'cp'); ?></label>
			</th>
			<td valign="middle"><input type="text" id="cp_prefix" name="cp_prefix" value="<?php echo get_option('cp_prefix'); ?>" size="20" /></td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="cp_suffix"><?php _e('Suffix for display of points:', 'cp'); ?></label>
			</th>
			<td valign="middle"><input type="text" id="cp_suffix" name="cp_suffix" value="<?php echo get_option('cp_suffix'); ?>" size="20" /></td>
		</tr>
	</table>
	<p class="submit">
		<input type="submit" name="Submit" value="<?php _e('Update Options','cp'); ?>" />
	</p>
</form>
</div>
<?php
}

function cp_admin_logs(){
	
	if ($_POST['cp_logs_enabled_do'] != '') {
	  $cp_logs_enabled = true;
	  update_option('cp_logs_enabled', $cp_logs_enabled);
	  echo '<div class="updated"><p><strong>'.__('Logs enabled','cp').'.</strong></p></div>';
	}

  ?>
	<div class="wrap">
	<h2>CubePoints - Logs</h2>
	<?php if (get_option('cp_logs_enabled')) { ?>
	<p><?php _e('Below is a list of most recent transactions.','cp'); ?></p>
		<table class="widefat fixed" cellspacing="0">
		<?php
		global $wpdb;
		$results = $wpdb->get_results('SELECT * FROM `'.CPDB.'` ORDER BY id DESC LIMIT 25 ');
		?>
			<thead><tr>
				<th scope="col"><?php _e('User Altered','cp'); ?></th><th scope="col"><?php _e('Amount of Points','cp'); ?></th><th scope="col"><?php _e('Type','cp'); ?></th><th scope="col"><?php _e('From','cp'); ?></th><th scope="col"><?php _e('Time','cp'); ?></th>
			</tr></thead><tfoot><tr>
				<th scope="col"><?php _e('User Altered','cp'); ?></th><th scope="col"><?php _e('Amount of Points','cp'); ?></th><th scope="col"><?php _e('Type','cp'); ?></th><th scope="col"><?php _e('From','cp'); ?></th><th scope="col"><?php _e('Time','cp'); ?></th>
			</tr></tfoot>
			<?php
			foreach($results as $result){
				$type='';
				$source='';
			
				switch ($result->type) {
				case "donate":
					if($result->points>0){
					$type=__('Donation','cp');
					$source = get_userdata($result->source)->user_login;
					}
					break;
				case "comment":
					if($result->points>0){
					$type=__('Comment Posted','cp');
					$source= 'Comment #' . $result->source;
					}
					else{
					$type=__('Comment Removed','cp');
					$source= 'Comment #' . $result->source;
					}
					break;
				case "post":
					$source = get_post($result->source);
					if($source->ID!=''){ $source= '<a href="' . $source->guid . '" title="'.$source->post_title.'">Post #'.$source->ID.'</a>' ;}
					else {$source= 'Post #'.$result->source;}
					$type=__('Published Post','cp');
					break;
				case "admin":
					$type=__('Administrative','cp');
					$source = get_userdata($result->source)->user_login;
					break;
				default:
					return false; 
					break;
				}
				$uid=get_userdata($result->uid)->user_login;
				if($uid!='' && $type!=''){
				if($source==''){$source='<i>' . __('unknown','cp') . '</i>';}
				?>
				<tr>
					<td><?php echo $uid; ?></td>
					<td><?php echo $result->points; ?></td>
					<td><?php echo $type; ?></td>
					<td><?php echo $source; ?></td>
					<td title="<?php echo date('Y-m-d H:i:s', $result->timestamp); ?>"><?php echo cp_relativeTime($result->timestamp); ?></td>
				</tr>
			<?php } } ?>
		
		</table>
	<?php } else { ?>


		<p><?php _e('Logs are disabled at the moment.','cp'); ?></p>
		<p><?php _e('With logs disabled, everytime a user updates a post, (s)he will receive a reward as if (s)he posted a post.','cp'); ?></p>
		<form method="post" action="">
		<p class="submit" style="padding-top:3px;"><input type="submit" name="cp_logs_enabled_do" value="<?php _e('Enable Logs','cp'); ?>" /></p>
		</form>
	<?php } ?>
	</div>
	<?php
}
function cp_admin()
{
  add_menu_page('CubePoints', 'CubePoints', 8, __FILE__, 'cp_admin_manage');
  add_submenu_page(__FILE__, 'Manage', __('Manage','cp'), 8, __FILE__, 'cp_admin_manage');
  add_submenu_page(__FILE__, 'Configure', __('Configure','cp'), 8, 'cp_admin_config', 'cp_admin_config');
  add_submenu_page(__FILE__, 'Logs', __('Logs','cp'), 8, 'cp_admin_logs', 'cp_admin_logs');
}
// widget
function cp_pointsWidget_init()
{
  // widget main
  function cp_pointsWidget($args)
  {
	  extract($args);
	  if (is_user_logged_in()) {
		  $options = get_option('cp_pointsWidget');?>
		  <?php echo $before_widget; ?>
		  <?php echo $before_title . $options['cp_pointsWidget_title'] . $after_title; ?>
		  <ul><li><?php echo $options['cp_pointsWidget_text']; ?> : <?php echo cp_displayPoints(); ?></li>
		  <?php if (get_option('cp_donation')){ ?>
		  <li><?php echo '<a href="'.PLUGIN_DIR.'actions.php?a=donate&height=166&width=500" title="'.__('Donate Points','cp').'" class="thickbox">'.__('Donate Points','cp').'</a>';?> </li></ul>
		  <?php } ?>
		  <?php echo $after_widget; ?>
	  <?php
	  }
  }
  register_sidebar_widget('CubePoints', 'cp_pointsWidget');
  // widget config
  function cp_pointsWidget_config()
  {
	  // Get our options and see if we're handling a form submission.
	  $options = get_option('cp_pointsWidget');
	  if (!is_array($options))
		  $options = array('cp_pointsWidget_title' => __('My Points','cp'), 'cp_pointsWidget_text' => __('Points','cp'));
	  if ($_POST['cp_pointsWidget_submit']) {
		  // Remember to sanitize and format use input appropriately.
		  $options['cp_pointsWidget_title'] = strip_tags(stripslashes($_POST['cp_pointsWidget_title']));
		  $options['cp_pointsWidget_text'] = strip_tags(stripslashes($_POST['cp_pointsWidget_text']));
		  update_option('cp_pointsWidget', $options);
	  }
	  // Be sure you format your options to be valid HTML attributes.
	  $cp_pointsWidget_title = htmlspecialchars($options['cp_pointsWidget_title'], ENT_QUOTES);
	  $cp_pointsWidget_text = htmlspecialchars($options['cp_pointsWidget_text'], ENT_QUOTES);
	  // Here is our little form segment. Notice that we don't need a
	  // complete form. This will be embedded into the existing form.
	  echo '<p><label for="cp_pointsWidget_title">' . __('Title:','cp') . '</label> <input type="text" class="widefat" id="cp_pointsWidget_title" name="cp_pointsWidget_title" value="' . $options['cp_pointsWidget_title'] . '"></p>';
	  echo '<p><label for="cp_pointsWidget_text">' . __('Text:','cp') . '</label> <input type="text" class="widefat" id="cp_pointsWidget_text" name="cp_pointsWidget_text" value="' . $options['cp_pointsWidget_text'] . '"></p>';
	  echo '<input type="hidden" id="cp_pointsWidget_submit" name="cp_pointsWidget_submit" value="1" />';
  }
  register_widget_control('CubePoints', 'cp_pointsWidget_config');


//2nd widget

  function cp_topPointsWidget($args)
  {
	  extract($args);

		  $options = get_option('cp_topPointsWidget');?>
		  <?php echo $before_widget; ?>
			<?php $count = $options['cp_topPointsWidget_num']; ?>
		  <?php echo $before_title . $options['cp_topPointsWidget_title'] . $after_title; ?>
		  <ul>
			<?php
				$arr = cp_getAllPoints();
				$i=0;
				while($i<$count){
					$data = $arr[$i];
					if($data['user_login']!=''){
					echo '<li><a href="'.PLUGIN_DIR.'actions.php?&a=info&quser='.$data['user_login'].'" class="cp_info jTip" id="cp_widget_info_'.$data['user_login'].'" name="Points">'.$data['user_login'].' ('.cp_formatPoints($data['meta_value']).')</a></li>';
					}
					$i++;
				}
			?>
		  </ul>
		  <?php echo $after_widget; ?>
	  <?php
  }
  register_sidebar_widget('CubePoints Top Users', 'cp_topPointsWidget');


  function cp_topPointsWidget_config()
  {
	  // Get our options and see if we're handling a form submission.
	  $options = get_option('cp_topPointsWidget');
	  if (!is_array($options))
		  $options = array('cp_topPointsWidget_title' => __('Top Users','cp'), 'cp_topPointsWidget_num' => 5);
	  if ($_POST['cp_topPointsWidget_submit']) {
		  // Remember to sanitize and format use input appropriately.
		  $options['cp_topPointsWidget_title'] = strip_tags(stripslashes($_POST['cp_topPointsWidget_title']));
		  $options['cp_topPointsWidget_num'] = (int) strip_tags(stripslashes($_POST['cp_topPointsWidget_num']));
		  if($options['cp_topPointsWidget_num']<1){$options['cp_topPointsWidget_num']=1;}
		  update_option('cp_topPointsWidget', $options);
	  }
	  // Be sure you format your options to be valid HTML attributes.
	  $cp_topPointsWidget_title = htmlspecialchars($options['cp_topPointsWidget_title'], ENT_QUOTES);
	  $cp_topPointsWidget_num = htmlspecialchars($options['cp_topPointsWidget_num'], ENT_QUOTES);
	  // Here is our little form segment. Notice that we don't need a
	  // complete form. This will be embedded into the existing form.
	  echo '<p><label for="cp_topPointsWidget_title">' . __('Title:','cp') . '</label> <input type="text" class="widefat" id="cp_topPointsWidget_title" name="cp_topPointsWidget_title" value="' . $options['cp_topPointsWidget_title'] . '"></p>';
	  echo '<p><label for="cp_topPointsWidget_num">' . __('Number of users to list:','cp') . '</label> <input type="text" class="widefat" id="cp_topPointsWidget_num" name="cp_topPointsWidget_num" value="' . $options['cp_topPointsWidget_num'] . '"></p>';
	  echo '<input type="hidden" id="cp_topPointsWidget_submit" name="cp_topPointsWidget_submit" value="1" />';
  }
  register_widget_control('CubePoints Top Users', 'cp_topPointsWidget_config');

}
add_action('widgets_init', 'cp_pointsWidget_init');
// donation - comments hook
function cp_addLink($content)
{
  if (is_user_logged_in()) {
	  global $comment;
	  $userinfo = get_userdata($comment->user_id);
	  if ($comment->user_id && $comment->user_id != cp_currentUser() && $userinfo->user_login != '') {
			  $content .= '<p id="cp_donate_p_' . get_comment_ID() . '"><a href="'.PLUGIN_DIR.'actions.php?a=donate&rcpt=' . get_comment_author() . '&height=166&width=500" title="'.__('Donate Points','cp').'" class="thickbox cp_donate_link">' . __('Donate Points','cp') . '</a> <a href="'.PLUGIN_DIR.'actions.php?a=pinfo&quser='.get_comment_author().'" class="cp_info jTip" id="cp_info_'.get_comment_ID().'" name="'.__('Points','cp').'">?</a></p>';
	  }
  }
  return $content;
}
if (get_option('cp_donation')) {
  add_filter('comment_text', 'cp_addLink', 1000);
}
// Hook for adding admin menus 
add_action('admin_menu', 'cp_admin');


function cp_header(){
	echo '<script type="text/javascript" src="' . PLUGIN_DIR . 'jquery.js"></script>';
	echo "\n";
	echo '<script type="text/javascript">var tb_pathToImage = "' . PLUGIN_DIR . 'loadingAnimation.gif";</script>';
	echo "\n";
	echo '<script type="text/javascript" src="' . PLUGIN_DIR . 'thickbox.js"></script>';
	echo "\n";
	echo '<link rel="stylesheet" href="' . PLUGIN_DIR . 'thickbox.css" type="text/css" media="screen" />';
	echo "\n";
	echo '<link rel="stylesheet" href="' . PLUGIN_DIR . 'cubepoints.css" type="text/css" media="screen" />';
	echo "\n";
	echo '<script type="text/javascript" src="' . PLUGIN_DIR . 'autocomplete.js"></script>';
	echo "\n";
	echo '<script type="text/javascript" src="' . PLUGIN_DIR . 'jquery.ajaxQueue.js"></script>';
	echo "\n";
	echo '<script type="text/javascript" src="' . PLUGIN_DIR . 'jquery.bgiframe.min.js"></script>';
	echo "\n";
	echo '<link rel="stylesheet" href="' . PLUGIN_DIR . 'autocomplete.css" type="text/css" media="screen" />';
	echo "\n";
	echo '<script type="text/javascript" src="' . PLUGIN_DIR . 'jtips.js"></script>';
	echo "\n";
	echo '<link rel="stylesheet" href="' . PLUGIN_DIR . 'jtips.css" type="text/css" media="screen" />';
	echo "\n";
}


// Hook for wordpress header
add_action('wp_head', 'cp_header');
// hook for installation of CubePoints 
register_activation_hook(__FILE__, 'cp_install');
?>